summaryrefslogtreecommitdiffstats
path: root/src/engine/events
diff options
context:
space:
mode:
Diffstat (limited to 'src/engine/events')
-rw-r--r--src/engine/events/DeleteEvent.cpp6
-rw-r--r--src/engine/events/DeleteEvent.hpp15
-rw-r--r--src/engine/events/MoveEvent.hpp13
3 files changed, 25 insertions, 9 deletions
diff --git a/src/engine/events/DeleteEvent.hpp b/src/engine/events/DeleteEvent.hpp
index d0fa43f1..05c47325 100644
--- a/src/engine/events/DeleteEvent.hpp
+++ b/src/engine/events/DeleteEvent.hpp
@@ -36,10 +36,19 @@ class DriverPort;
class DisconnectAllEvent;
class CompiledPatch;
-
-/** Delete a graph object.
- * WebDAV method DELETE (RFC4918 S9.6).
+/** \page methods
+ * <h2>DELETE</h2>
+ * From WebDAV (RFC4918 S9.6).
+ *
+ * Calling DELETE on an object will remove that object from the engine
+ * (i.e. stop executing it) and destroy it.
*
+ * \li All properties of the object are lost
+ * \li All references to the object are lost (e.g. the parent's reference to
+ * this child is lost, any connections to the object are removed, etc.)
+ */
+
+/** DELETE a graph object (see \ref methods).
* \ingroup engine
*/
class DeleteEvent : public QueuedEvent
diff --git a/src/engine/events/MoveEvent.hpp b/src/engine/events/MoveEvent.hpp
index f55d70b1..7b77439f 100644
--- a/src/engine/events/MoveEvent.hpp
+++ b/src/engine/events/MoveEvent.hpp
@@ -26,10 +26,17 @@ namespace Ingen {
class PatchImpl;
-
-/** Move a graph object to a new path.
- * WebDAV method MOVE (RFC4918 S9.9).
+/** \page methods
+ * <h2>MOVE</h2>
+ * From WebDAV (RFC4918 S9.9).
+ *
+ * Calling MOVE on an object removes it from its current location
+ * and inserts it at a new one in a single operation.
*
+ * MOVE to a path with a different parent is currently not supported.
+ */
+
+/** MOVE a graph object to a new path (see \ref methods).
* \ingroup engine
*/
class MoveEvent : public QueuedEvent
diff --git a/src/engine/events/DeleteEvent.cpp b/src/engine/events/DeleteEvent.cpp
index 21058546..958a8d42 100644
--- a/src/engine/events/DeleteEvent.cpp
+++ b/src/engine/events/DeleteEvent.cpp
@@ -88,7 +88,7 @@ DeleteEvent::pre_process()
// FIXME: is this called multiple times?
_compiled_patch = _node->parent_patch()->compile();
#ifndef NDEBUG
// Be sure node is removed from process order, so it can be destroyed
for (size_t i=0; i < _compiled_patch->size(); ++i) {
assert(_compiled_patch->at(i).node() != _node.get());
// FIXME: check providers/dependants too
@@ -187,7 +187,7 @@ DeleteEvent::post_process()
_engine.broadcaster()->bundle_begin();
if (_disconnect_event)
_disconnect_event->post_process();
- _engine.broadcaster()->send_destroyed(_path);
+ _engine.broadcaster()->send_deleted(_path);
_engine.broadcaster()->bundle_end();
_engine.maid()->push(_patch_node_listnode);
} else if (_patch_port_listnode) {
@@ -196,7 +196,7 @@ DeleteEvent::post_process()
_engine.broadcaster()->bundle_begin();
if (_disconnect_event)
_disconnect_event->post_process();
- _engine.broadcaster()->send_destroyed(_path);
+ _engine.broadcaster()->send_deleted(_path);
_engine.broadcaster()->bundle_end();
_engine.maid()->push(_patch_port_listnode);
} else {
@@ -88,7 +88,7 @@ DeleteEvent::pre_process()
_compiled_patch = _node->parent_patch()->compile();
#ifndef NDEBUG
- // Be sure node is removed from process order, so it can be destroyed
+ // Be sure node is removed from process order, so it can be deleted
for (size_t i=0; i < _compiled_patch->size(); ++i) {
assert(_compiled_patch->at(i).node() != _node.get());